@@ -29,6 +29,10 @@ extern "C" int initializeWinsockIfNecessary();
 #include <sys/time.h>
 #if !defined(_WIN32)
 #include <netinet/tcp.h>
+#ifdef __ANDROID_NDK__
+#include <android/ndk-version.h>
+#define ANDROID_OLD_NDK __NDK_MAJOR__ < 17
+#endif
 #endif
 #include <fcntl.h>
 #define initializeWinsockIfNecessary() 1
@@ -563,7 +567,7 @@ Boolean socketJoinGroupSSM(UsageEnvironment& env, int socket,
   if (!IsMulticastAddress(groupAddress)) return True; // ignore this case
 
   struct ip_mreq_source imr;
-#ifdef __ANDROID__
+#if ANDROID_OLD_NDK
     imr.imr_multiaddr = groupAddress;
     imr.imr_sourceaddr = sourceFilterAddr;
     imr.imr_interface = ReceivingInterfaceAddr;
@@ -589,7 +593,7 @@ Boolean socketLeaveGroupSSM(UsageEnvironment& /*env*/, int socket,
   if (!IsMulticastAddress(groupAddress)) return True; // ignore this case
 
   struct ip_mreq_source imr;
-#ifdef __ANDROID__
+#if ANDROID_OLD_NDK
     imr.imr_multiaddr = groupAddress;
     imr.imr_sourceaddr = sourceFilterAddr;
     imr.imr_interface = ReceivingInterfaceAddr;
@@ -885,3 +889,4 @@ int gettimeofday(struct timeval* tp, int* /*tz*/) {
   return 0;
 }
 #endif
+#undef ANDROID_OLD_NDK
